@@ -1,4 +1,3 @@
-from celeryconfig import PYAPNS
 from pyapns import configure, provision, notify
 from push import PushBase
 
@@ -12,8 +11,9 @@ class APN(PushBase):
             self.message_data = data['message_data']
         except KeyError:
             self.message_data = False
-        configure(PYAPNS)
-        provision(self.config['provision'], open(self.config['certfile']).read(), self.config['environment'])
+        configure(data['config']['PYAPNS'])
+        provision(self.config['provision'], open(
+            self.config['certfile']).read(), self.config['environment'])
 
     def check_token():
         pass
